@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * The Sushi project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Sushi. This
@@ -25,7 +23,12 @@
  *
  */
 
-let Constants = imports.util.constants;
+const Gdk = imports.gi.Gdk;
+const Gtk = imports.gi.Gtk;
+
+const Lang = imports.lang;
+
+const Constants = imports.util.constants;
 
 let slowDownFactor = 0;
 
@@ -102,13 +105,13 @@ function createToolButton(iconName, callback) {
 }
 
 function createFullScreenButton(mainWindow) {
-    return createToolButton('view-fullscreen-symbolic', Lang.bind(this, function() {
+    return createToolButton('view-fullscreen-symbolic', function() {
         mainWindow.toggleFullScreen();
-    }));
+    });
 }
 
 function createOpenButton(file, mainWindow) {
-    return createToolButton('document-open-symbolic', Lang.bind(this, function(widget) {
+    return createToolButton('document-open-symbolic', function(widget) {
         let timestamp = Gtk.get_current_event_time();
         try {
             Gtk.show_uri(widget.get_screen(),
@@ -120,7 +123,7 @@ function createOpenButton(file, mainWindow) {
             log('Unable to execute the default application for ' +
                 file.get_uri() + ' : ' + e.toString());
         }
-    }));
+    });
 }
 
 function formatTimeString(timeVal) {
