@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * The Sushi project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Sushi. This
@@ -25,18 +23,19 @@
  *
  */
 
-let MimeHandler = imports.ui.mimeHandler;
-let GtkClutter = imports.gi.GtkClutter;
-let Gtk = imports.gi.Gtk;
-let GLib = imports.gi.GLib;
+const MimeHandler = imports.ui.mimeHandler;
+const Utils = imports.ui.utils;
 
-let Sushi = imports.gi.Sushi;
+const Lang = imports.lang;
 
-function FontRenderer(args) {
-    this._init(args);
-}
+const GtkClutter = imports.gi.GtkClutter;
+const Gtk = imports.gi.Gtk;
+const GLib = imports.gi.GLib;
+const Sushi = imports.gi.Sushi;
+
+const FontRenderer = new Lang.Class({
+    Name: 'FontRenderer',
 
-FontRenderer.prototype = {
     _init : function(args) {
         this.moveOnClick = true;
         this.canFullScreen = true;
@@ -76,7 +75,7 @@ FontRenderer.prototype = {
 
         return size;
     }
-}
+});
 
 let handler = new MimeHandler.MimeHandler();
 let renderer = new FontRenderer();
